@@ -179,7 +179,7 @@ class monday_endpoints:
         """
         Gets all boards the user has access to.
         """
-        board_request = self.make_request("query { boards (limit:25, page:0) { id name state board_folder_id workspace_id owner { id }}}")
+        board_request = self.make_request("query { boards (limit:25, page:0) { id name state board_folder_id workspace_id owner { id } type }}")
             
         if workspace_id:
             board_request = [x for x in board_request if x['workspace_id'] == workspace_id]
